@@ -59,6 +59,15 @@ class Instances(JavaObject):
         """
         return InstanceIterator(self)
 
+    def __len__(self):
+        """
+        Returns the number of rows in the dataset.
+
+        :return: the number of Instance objects
+        :rtype: int
+        """
+        return self.num_instances
+
     @property
     def relationname(self):
         """
@@ -302,6 +311,17 @@ class Instances(JavaObject):
         """
         javabridge.call(self.jobject, "deleteWithMissing", "(I)V", index)
 
+    def insert_attribute(self, att, index):
+        """
+        Inserts the attribute at the specified location.
+
+        :param att: the attribute to insert
+        :type att: Attribute
+        :param index: the index to insert the attribute at
+        :type index: int
+        """
+        javabridge.call(self.jobject, "insertAttributeAt", "(Lweka/core/Attribute;I)V", att.jobject, index)
+
     def compactify(self):
         """
         Compactifies the set of instances.
@@ -1164,6 +1184,20 @@ class Attribute(JavaObject):
             javabridge.make_instance(
                 "weka/core/Attribute", "(Ljava/lang/String;Ljava/util/List;)V", name, None))
 
+    @classmethod
+    def create_relational(cls, name, inst):
+        """
+        Creates a relational attribute.
+
+        :param name: the name of the attribute
+        :type name: str
+        :param inst: the structure of the relational attribute
+        :type inst: Instances
+        """
+        return Attribute(
+            javabridge.make_instance(
+                "weka/core/Attribute", "(Ljava/lang/String;Lweka/core/Instances;)V", name, inst.jobject))
+
 
 class AttributeStats(JavaObject):
     """
